@@ -1,4 +1,5 @@
-# Copyright (C) 2018-2020 2ndQuadrant Limited
+# -*- coding: utf-8 -*-
+# © Copyright EnterpriseDB UK Limited 2018-2021
 #
 # This file is part of Barman.
 #
@@ -25,7 +26,9 @@ from contextlib import closing
 from io import BytesIO
 
 import barman
-from barman.cloud import CloudInterface, configure_logging
+from barman.cloud import configure_logging
+from barman.cloud_providers import get_cloud_interface
+from barman.exceptions import BarmanException
 from barman.utils import force_str
 from barman.xlog import hash_dir, is_any_xlog_file
 
@@ -35,6 +38,23 @@ except ImportError:
     raise SystemExit("Missing required python module: argparse")
 
 
+def __is_hook_script():
+    """Check the environment and determine if we are running as a hook script"""
+    if "BARMAN_HOOK" in os.environ and "BARMAN_PHASE" in os.environ:
+        if (
+            os.getenv("BARMAN_HOOK") in ("archive_script", "archive_retry_script")
+            and os.getenv("BARMAN_PHASE") == "pre"
+        ):
+            return True
+        else:
+            raise BarmanException(
+                "barman-cloud-wal-archive called as unsupported hook script: %s_%s"
+                % (os.getenv("BARMAN_PHASE"), os.getenv("BARMAN_HOOK"))
+            )
+    else:
+        return False
+
+
 def main(args=None):
     """
     The main script entry point
@@ -45,23 +65,29 @@ def main(args=None):
     config = parse_arguments(args)
     configure_logging(config)
 
+    # Read wal_path from environment if we're a hook script
+    if __is_hook_script():
+        if "BARMAN_FILE" not in os.environ:
+            raise BarmanException("Expected environment variable BARMAN_FILE not set")
+        config.wal_path = os.getenv("BARMAN_FILE")
+    else:
+        if config.wal_path is None:
+            raise BarmanException("the following arguments are required: wal_path")
+
     # Validate the WAL file name before uploading it
     if not is_any_xlog_file(config.wal_path):
-        logging.error('%s is an invalid name for a WAL file' % config.wal_path)
+        logging.error("%s is an invalid name for a WAL file" % config.wal_path)
         raise SystemExit(1)
 
     try:
-        cloud_interface = CloudInterface(
-            url=config.destination_url,
-            encryption=config.encryption,
-            profile_name=config.profile,
-            endpoint_url=config.endpoint_url)
+        cloud_interface = get_cloud_interface(config)
 
         with closing(cloud_interface):
-            uploader = S3WalUploader(
+            uploader = CloudWalUploader(
                 cloud_interface=cloud_interface,
                 server_name=config.server_name,
-                compression=config.compression)
+                compression=config.compression,
+            )
 
             if not cloud_interface.test_connectivity():
                 raise SystemExit(1)
@@ -74,9 +100,8 @@ def main(args=None):
 
             uploader.upload_wal(config.wal_path)
     except Exception as exc:
-        logging.error("Barman cloud WAL archiver exception: %s",
-                      force_str(exc))
-        logging.debug('Exception details:', exc_info=exc)
+        logging.error("Barman cloud WAL archiver exception: %s", force_str(exc))
+        logging.debug("Exception details:", exc_info=exc)
         raise SystemExit(1)
 
 
@@ -88,91 +113,113 @@ def parse_arguments(args=None):
     """
 
     parser = argparse.ArgumentParser(
-        description='This script can be used in the `archive_command` '
-                    'of a PostgreSQL server to ship WAL files to the Cloud. '
-                    'Currently only AWS S3 is supported.',
-        add_help=False
+        description="This script can be used in the `archive_command` "
+        "of a PostgreSQL server to ship WAL files to the Cloud. "
+        "Currently AWS S3 and Azure Blob Storage are supported.",
+        add_help=False,
     )
     parser.add_argument(
-        'destination_url',
-        help='URL of the cloud destination, such as a bucket in AWS S3.'
-             ' For example: `s3://bucket/path/to/folder`.'
+        "destination_url",
+        help="URL of the cloud destination, such as a bucket in AWS S3."
+        " For example: `s3://bucket/path/to/folder`.",
     )
     parser.add_argument(
-        'server_name',
-        help='the name of the server as configured in Barman.'
+        "server_name", help="the name of the server as configured in Barman."
     )
     parser.add_argument(
-        'wal_path',
-        help="the value of the '%%p' keyword"
-             " (according to 'archive_command')."
+        "wal_path",
+        nargs="?",
+        help="the value of the '%%p' keyword" " (according to 'archive_command').",
+        default=None,
     )
     parser.add_argument(
-        '-V', '--version',
-        action='version', version='%%(prog)s %s' % barman.__version__
+        "-V", "--version", action="version", version="%%(prog)s %s" % barman.__version__
     )
-    parser.add_argument(
-        '--help',
-        action='help',
-        help='show this help message and exit')
+    parser.add_argument("--help", action="help", help="show this help message and exit")
     verbosity = parser.add_mutually_exclusive_group()
     verbosity.add_argument(
-        '-v', '--verbose',
-        action='count',
+        "-v",
+        "--verbose",
+        action="count",
         default=0,
-        help='increase output verbosity (e.g., -vv is more than -v)')
+        help="increase output verbosity (e.g., -vv is more than -v)",
+    )
     verbosity.add_argument(
-        '-q', '--quiet',
-        action='count',
+        "-q",
+        "--quiet",
+        action="count",
         default=0,
-        help='decrease output verbosity (e.g., -qq is less than -q)')
-    parser.add_argument(
-        '-P', '--profile',
-        help='profile name (e.g. INI section in AWS credentials file)',
+        help="decrease output verbosity (e.g., -qq is less than -q)",
     )
     compression = parser.add_mutually_exclusive_group()
     compression.add_argument(
-        "-z", "--gzip",
+        "-z",
+        "--gzip",
         help="gzip-compress the WAL while uploading to the cloud",
-        action='store_const',
-        const='gzip',
-        dest='compression',
+        action="store_const",
+        const="gzip",
+        dest="compression",
     )
     compression.add_argument(
-        "-j", "--bzip2",
+        "-j",
+        "--bzip2",
         help="bzip2-compress the WAL while uploading to the cloud",
-        action='store_const',
-        const='bzip2',
-        dest='compression',
+        action="store_const",
+        const="bzip2",
+        dest="compression",
     )
     parser.add_argument(
-        "-e", "--encryption",
-        help="Enable server-side encryption for the transfer. "
-             "Allowed values: 'AES256', 'aws:kms'",
-        choices=['AES256', 'aws:kms'],
-        metavar="ENCRYPTION",
-    )
-    parser.add_argument(
-        "-t", "--test",
+        "-t",
+        "--test",
         help="Test cloud connectivity and exit",
         action="store_true",
-        default=False
+        default=False,
     )
     parser.add_argument(
+        "--cloud-provider",
+        help="The cloud provider to use as a storage backend",
+        choices=["aws-s3", "azure-blob-storage"],
+        default="aws-s3",
+    )
+    s3_arguments = parser.add_argument_group(
+        "Extra options for the aws-s3 cloud provider"
+    )
+    s3_arguments.add_argument(
         "--endpoint-url",
         help="Override default S3 endpoint URL with the given one",
     )
+    s3_arguments.add_argument(
+        "-P",
+        "--profile",
+        help="profile name (e.g. INI section in AWS credentials file)",
+    )
+    s3_arguments.add_argument(
+        "-e",
+        "--encryption",
+        help="The encryption algorithm used when storing the uploaded data in S3. "
+        "Allowed values: 'AES256'|'aws:kms'.",
+        choices=["AES256", "aws:kms"],
+        metavar="ENCRYPTION",
+    )
+    azure_arguments = parser.add_argument_group(
+        "Extra options for the azure-blob-storage cloud provider"
+    )
+    azure_arguments.add_argument(
+        "--encryption-scope",
+        help="The name of an encryption scope defined in the Azure Blob Storage "
+        "service which is to be used to encrypt the data in Azure",
+    )
     return parser.parse_args(args=args)
 
 
-class S3WalUploader(object):
+class CloudWalUploader(object):
     """
-    S3 upload client
+    Cloud storage upload client
     """
-    def __init__(self, cloud_interface,
-                 server_name, compression=None):
+
+    def __init__(self, cloud_interface, server_name, compression=None):
         """
-        Object responsible for handling interactions with S3
+        Object responsible for handling interactions with cloud storage
 
         :param CloudInterface cloud_interface: The interface to use to
           upload the backup
@@ -186,7 +233,7 @@ class S3WalUploader(object):
 
     def upload_wal(self, wal_path):
         """
-        Upload a WAL file from postgres to S3
+        Upload a WAL file from postgres to cloud storage
 
         :param str wal_path: Full path of the WAL file
         """
@@ -194,20 +241,18 @@ class S3WalUploader(object):
         wal_name = self.retrieve_wal_name(wal_path)
         # Use the correct file object for the upload (simple|gzip|bz2)
         file_object = self.retrieve_file_obj(wal_path)
-        # Correctly format the destination path on s3
+        # Correctly format the destination path
         destination = os.path.join(
             self.cloud_interface.path,
             self.server_name,
-            'wals',
+            "wals",
             hash_dir(wal_path),
-            wal_name
+            wal_name,
         )
 
         # Put the file in the correct bucket.
         # The put method will handle automatically multipart upload
-        self.cloud_interface.upload_fileobj(
-            fileobj=file_object,
-            key=destination)
+        self.cloud_interface.upload_fileobj(fileobj=file_object, key=destination)
 
     def retrieve_file_obj(self, wal_path):
         """
@@ -229,22 +274,22 @@ class S3WalUploader(object):
         :return File: simple or compressed file object
         """
         # Read the wal_file in binary mode
-        wal_file = open(wal_path, 'rb')
+        wal_file = open(wal_path, "rb")
         # return the opened file if is uncompressed
         if not self.compression:
             return wal_file
 
-        if self.compression == 'gzip':
+        if self.compression == "gzip":
             # Create a BytesIO for in memory compression
             in_mem_gzip = BytesIO()
             # TODO: closing is redundant with python >= 2.7
-            with closing(gzip.GzipFile(fileobj=in_mem_gzip, mode='wb')) as gz:
+            with closing(gzip.GzipFile(fileobj=in_mem_gzip, mode="wb")) as gz:
                 # copy the gzipped data in memory
                 shutil.copyfileobj(wal_file, gz)
             in_mem_gzip.seek(0)
             return in_mem_gzip
 
-        elif self.compression == 'bzip2':
+        elif self.compression == "bzip2":
             # Create a BytesIO for in memory compression
             in_mem_bz2 = BytesIO(bz2.compress(wal_file.read()))
             in_mem_bz2.seek(0)
@@ -270,16 +315,16 @@ class S3WalUploader(object):
         if not self.compression:
             return wal_name
 
-        if self.compression == 'gzip':
+        if self.compression == "gzip":
             # add gz extension
             return "%s.gz" % wal_name
 
-        elif self.compression == 'bzip2':
+        elif self.compression == "bzip2":
             # add bz2 extension
             return "%s.bz2" % wal_name
         else:
             raise ValueError("Unknown compression type: %s" % self.compression)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
