@@ -1,4 +1,5 @@
-# Copyright (C) 2018-2020 2ndQuadrant Limited
+# -*- coding: utf-8 -*-
+# © Copyright EnterpriseDB UK Limited 2018-2021
 #
 # This file is part of Barman.
 #
@@ -20,7 +21,8 @@ import os
 from contextlib import closing
 
 import barman
-from barman.cloud import CloudInterface, configure_logging
+from barman.cloud import configure_logging
+from barman.cloud_providers import get_cloud_interface
 from barman.utils import force_str
 from barman.xlog import hash_dir, is_any_xlog_file, is_backup_file
 
@@ -42,20 +44,16 @@ def main(args=None):
 
     # Validate the WAL file name before downloading it
     if not is_any_xlog_file(config.wal_name):
-        logging.error('%s is an invalid name for a WAL file' % config.wal_name)
+        logging.error("%s is an invalid name for a WAL file" % config.wal_name)
         raise SystemExit(1)
 
     try:
-        cloud_interface = CloudInterface(
-            url=config.source_url,
-            encryption=config.encryption,
-            profile_name=config.profile,
-            endpoint_url=config.endpoint_url)
+        cloud_interface = get_cloud_interface(config)
 
         with closing(cloud_interface):
-            downloader = S3WalDownloader(
-                cloud_interface=cloud_interface,
-                server_name=config.server_name)
+            downloader = CloudWalDownloader(
+                cloud_interface=cloud_interface, server_name=config.server_name
+            )
 
             if not cloud_interface.test_connectivity():
                 raise SystemExit(1)
@@ -64,16 +62,14 @@ def main(args=None):
                 raise SystemExit(0)
 
             if not cloud_interface.bucket_exists:
-                logging.error("Bucket %s does not exist",
-                              cloud_interface.bucket_name)
+                logging.error("Bucket %s does not exist", cloud_interface.bucket_name)
                 raise SystemExit(1)
 
             downloader.download_wal(config.wal_name, config.wal_dest)
 
     except Exception as exc:
-        logging.error("Barman cloud WAL restore exception: %s",
-                      force_str(exc))
-        logging.debug('Exception details:', exc_info=exc)
+        logging.error("Barman cloud WAL restore exception: %s", force_str(exc))
+        logging.debug("Exception details:", exc_info=exc)
         raise SystemExit(1)
 
 
@@ -85,87 +81,87 @@ def parse_arguments(args=None):
     """
 
     parser = argparse.ArgumentParser(
-        description='This script can be used as a `restore_command` '
-                    'to download WAL files previously archived with '
-                    'barman-cloud-wal-archive command. '
-                    'Currently only AWS S3 is supported.',
-        add_help=False
+        description="This script can be used as a `restore_command` "
+        "to download WAL files previously archived with "
+        "barman-cloud-wal-archive command. "
+        "Currently AWS S3 and Azure Blob Storage are supported.",
+        add_help=False,
     )
 
     parser.add_argument(
-        'source_url',
-        help='URL of the cloud source, such as a bucket in AWS S3.'
-             ' For example: `s3://bucket/path/to/folder`.'
+        "source_url",
+        help="URL of the cloud source, such as a bucket in AWS S3."
+        " For example: `s3://bucket/path/to/folder`.",
     )
     parser.add_argument(
-        'server_name',
-        help='the name of the server as configured in Barman.'
+        "server_name", help="the name of the server as configured in Barman."
     )
     parser.add_argument(
         "wal_name",
-        help="The value of the '%%f' keyword "
-             "(according to 'restore_command').",
+        help="The value of the '%%f' keyword " "(according to 'restore_command').",
     )
     parser.add_argument(
         "wal_dest",
-        help="The value of the '%%p' keyword "
-             "(according to 'restore_command').",
+        help="The value of the '%%p' keyword " "(according to 'restore_command').",
     )
     parser.add_argument(
-        '-V', '--version',
-        action='version', version='%%(prog)s %s' % barman.__version__
+        "-V", "--version", action="version", version="%%(prog)s %s" % barman.__version__
     )
-    parser.add_argument(
-        '--help',
-        action='help',
-        help='show this help message and exit')
+    parser.add_argument("--help", action="help", help="show this help message and exit")
     verbosity = parser.add_mutually_exclusive_group()
     verbosity.add_argument(
-        '-v', '--verbose',
-        action='count',
+        "-v",
+        "--verbose",
+        action="count",
         default=0,
-        help='increase output verbosity (e.g., -vv is more than -v)')
+        help="increase output verbosity (e.g., -vv is more than -v)",
+    )
     verbosity.add_argument(
-        '-q', '--quiet',
-        action='count',
+        "-q",
+        "--quiet",
+        action="count",
         default=0,
-        help='decrease output verbosity (e.g., -qq is less than -q)')
-    parser.add_argument(
-        '-P', '--profile',
-        help='profile name (e.g. INI section in AWS credentials file)',
+        help="decrease output verbosity (e.g., -qq is less than -q)",
     )
     parser.add_argument(
-        "-e", "--encryption",
-        help="Enable server-side encryption for the transfer. "
-             "Allowed values: 'AES256', 'aws:kms'",
-        choices=['AES256', 'aws:kms'],
-        metavar="ENCRYPTION",
-    )
-    parser.add_argument(
-        "-t", "--test",
+        "-t",
+        "--test",
         help="Test cloud connectivity and exit",
         action="store_true",
-        default=False
+        default=False,
     )
     parser.add_argument(
+        "--cloud-provider",
+        help="The cloud provider to use as a storage backend",
+        choices=["aws-s3", "azure-blob-storage"],
+        default="aws-s3",
+    )
+    s3_arguments = parser.add_argument_group(
+        "Extra options for the aws-s3 cloud provider"
+    )
+    s3_arguments.add_argument(
         "--endpoint-url",
         help="Override default S3 endpoint URL with the given one",
     )
+    s3_arguments.add_argument(
+        "-P",
+        "--profile",
+        help="profile name (e.g. INI section in AWS credentials file)",
+    )
     return parser.parse_args(args=args)
 
 
-class S3WalDownloader(object):
+class CloudWalDownloader(object):
     """
-    S3 download client
+    Cloud storage download client
     """
 
     # Allowed compression algorithms
-    ALLOWED_COMPRESSIONS = {'.gz': 'gzip', '.bz2': 'bzip2'}
+    ALLOWED_COMPRESSIONS = {".gz": "gzip", ".bz2": "bzip2"}
 
-    def __init__(self, cloud_interface,
-                 server_name):
+    def __init__(self, cloud_interface, server_name):
         """
-        Object responsible for handling interactions with S3
+        Object responsible for handling interactions with cloud storage
 
         :param CloudInterface cloud_interface: The interface to use to
           upload the backup
@@ -177,7 +173,7 @@ class S3WalDownloader(object):
 
     def download_wal(self, wal_name, wal_dest):
         """
-        Download a WAL file from S3
+        Download a WAL file from cloud storage
 
         :param str wal_name: Name of the WAL file
         :param str wal_dest: Full path of the destination WAL file
@@ -185,10 +181,7 @@ class S3WalDownloader(object):
 
         # Correctly format the source path on s3
         source_dir = os.path.join(
-            self.cloud_interface.path,
-            self.server_name,
-            'wals',
-            hash_dir(wal_name)
+            self.cloud_interface.path, self.server_name, "wals", hash_dir(wal_name)
         )
         # Add a path separator if needed
         if not source_dir.endswith(os.path.sep):
@@ -208,9 +201,9 @@ class S3WalDownloader(object):
                 # Detect compression
                 basename = item
                 for e, c in self.ALLOWED_COMPRESSIONS.items():
-                    if item[-len(e):] == e:
+                    if item[-len(e) :] == e:
                         # Strip extension
-                        basename = basename[:-len(e)]
+                        basename = basename[: -len(e)]
                         compression = c
                         break
 
@@ -225,22 +218,29 @@ class S3WalDownloader(object):
 
                 # Found candidate
                 remote_name = item
-                logging.info("Found WAL %s for server %s as %s",
-                             wal_name, self.server_name, remote_name)
+                logging.info(
+                    "Found WAL %s for server %s as %s",
+                    wal_name,
+                    self.server_name,
+                    remote_name,
+                )
                 break
 
         if not remote_name:
-            logging.info("WAL file %s for server %s does not exists",
-                         wal_name, self.server_name)
+            logging.info(
+                "WAL file %s for server %s does not exists", wal_name, self.server_name
+            )
             raise SystemExit(1)
 
         # Download the file
-        logging.debug("Downloading %s to %s (%s)",
-                      remote_name, wal_dest,
-                      "decompressing " + compression if compression
-                      else "no compression")
+        logging.debug(
+            "Downloading %s to %s (%s)",
+            remote_name,
+            wal_dest,
+            "decompressing " + compression if compression else "no compression",
+        )
         self.cloud_interface.download_file(remote_name, wal_dest, compression)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
